@@ -32,6 +32,8 @@
  * 02110-1301 USA.
  */
 
+#define _DEFAULT_SOURCE
+
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -41,6 +43,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/ioctl.h>
+#include <sys/select.h>
 #include <termios.h>
 #include <unistd.h>
 #ifdef SYSTEMD_SUPPORT
@@ -861,6 +864,9 @@ static struct input_types input_types[] = {
 { "--wacom_iv",		"-wacom_iv",	"Wacom protocol IV tablet",
 	B9600, CS8 | CRTSCTS,
 	SERIO_WACOM_IV,		0x00,	0x00,	0,	wacom_iv_init },
+{ "--pulse8-cec",		"-pulse8-cec",	"Pulse Eight HDMI CEC dongle",
+	B9600, CS8,
+	SERIO_PULSE8_CEC,		0x00,	0x00,	0,	NULL },
 { NULL, NULL, NULL, 0, 0, 0, 0, 0, 0, NULL }
 };
 
